@@ -170,7 +170,7 @@ pub struct libssh2_knownhost {
 }
 
 #[repr(C)]
-#[deriving(Copy)]
+#[derive(Copy)]
 pub struct LIBSSH2_SFTP_ATTRIBUTES {
     pub flags: c_ulong,
     pub filesize: u64,
@@ -182,7 +182,7 @@ pub struct LIBSSH2_SFTP_ATTRIBUTES {
 }
 
 #[repr(C)]
-#[deriving(Copy)]
+#[derive(Copy)]
 pub struct LIBSSH2_SFTP_STATVFS {
     pub f_bsize: u64,
     pub f_frsize: u64,
